==> mediawiki-1.15.1.tar.gz: mediawiki-1.15.1/languages/messages/MessagesNiu.php <==
<?php
/** Niuean (ko e vagahau Niuē)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Rotemliss
 * @author Sioneholof
 */

$messages = array(
# Dates
'sunday'        => 'Aho Tapu',
'monday'        => 'Aho Gofua',
'tuesday'       => 'Aho Ua',
'wednesday'     => 'Aho Lotu',
'thursday'      => 'Aho Tuloto',
'friday'        => 'Aho Falaile',
'saturday'      => 'Aho Faiumu',
'january'       => 'Ianuali',
'february'      => 'Fepuali',
'march'         => 'Masi',
'april'         => 'Apelila',
'may_long'      => 'Me',
'june'          => 'Iuni',
'july'          => 'Iulai',
'august'        => 'Aokuso',
'september'     => 'Sepetema',
'october'       => 'Oketopa',
'november'      => 'Novema',
'december'      => 'Tesemo',
'january-gen'   => 'Ianuali',
'february-gen'  => 'Fepuali',
'march-gen'     => 'Masi',
'april-gen'     => 'Apelila',
'may-gen'       => 'Me',
'june-gen'      => 'Iuni',
'july-gen'      => 'Iulai',
'august-gen'    => 'Aokuso',
'september-gen' => 'Sepetema',
'october-gen'   => 'Oketopa',
'november-gen'  => 'Novema',
'december-gen'  => 'Tesemo',
'may'           => 'Me',

'article'        => 'Tohi Tala',
'cancel'         => 'Tiaki',
'qbedit'         => 'Fakahakohako',
'qbspecialpages' => 'Tau Lau Mahuiga',
'mytalk'         => 'Haaku tutala',
'navigation'     => 'Navikati',

'help'             => 'Lagomatai',
'search'           => 'Kumi',
'searchbutton'     => 'Kumi',
'go'               => 'Fano',
'searcharticle'    => 'Fano',
'history_short'    => 'Liu onoono atu ki tua',
'printableversion' => 'Mitaki lolomi',
'permalink'        => 'Matutakiaga mautumau',
'edit'             => 'Fakahakohako',
'delete'           => 'Tamate',
'protect'          => 'Puipui',
'talk'             => 'Fakatutala',
'toolbox'          => 'Puha Mena Gahua',
'otherlanguages'   => 'Ke he falu vagahau',
'jumptonavigation' => 'navikati',
'jumptosearch'     => 'kumi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Hagaao ke he {{SITENAME}}',
'currentevents'        => 'Tau Fakaholoaga Mogonei',
'edithelp'             => 'Lagomatai ke he Fakahakohako',
'mainpage'             => 'Matapatu Lau',
'mainpage-description' => 'Matapatu Lau',
'portal'               => 'Maaga ke Matutaki',
'privacy'              => 'Ko e puipuiaga ke he tau talahauaga mo e talahauaga fakatagata',

'youhavenewmessages'      => 'Fai $1 ($2).',
'newmessageslink'         => 'tau tohi foou',
'youhavenewmessagesmulti' => 'Fai tohi foou a koe he $1',
'editsection'             => 'fakahakohako',
'editold'                 => 'fakahakohako',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Lau he tagata',

# General errors
'viewsource' => 'Kitekite ke mouaga',

# Login and logout pages
'welcomecreation'         => '== Fakalofa atu, kua fiafia ke hu mai ==
Kua talaga e haau a poko.
Ua nimo ke hiki e haau tau manako {{SITENAME}}.',
'yourname'                => 'Matahigoa he tagata:',
'yourpassword'            => 'Kupu fufu:',
'yourpasswordagain'       => 'Liu lolomi e kupu fufu:',
'remembermypassword'      => 'Manatu e haaku loko ini',
'login'                   => 'Hu ki loto',
'nav-login-createaccount' => 'Hu ki loto / talaga e poko',
'userlogin'               => 'Hu ki loto / talaga e poko',
'logout'                  => 'Hu mai ki tua',
'userlogout'              => 'Hu mai ki tua',
'notloggedin'             => 'Ai la hu ki loto',
'createaccount'           => 'Talaga e poko',
'gotaccountlink'          => 'Hu ki loto',
'youremail'               => 'Meli hila:',
'username'                => 'Matahigoa he tagata:',
'email'                   => 'Meli hila',

# Edit pages
'summary'            => 'Fakakatoakatoa:',
'minoredit'          => 'Ko e fakahakohako fakatote',
'watchthis'          => 'Onoono e lau e',
'savearticle'        => 'Taofi e lau',
'showpreview'        => 'Fakakite e foliga',
'showdiff'           => 'Fakakite e tau hikihiki',
'whitelistedittitle' => 'Kua lata ke loko ini ke fakahakohako',
'loginreqlink'       => 'hu ki loto',

# History pages
'currentrev'          => 'Kitekiteaga mogonei',
'currentrevisionlink' => 'Kitekiteaga mogonei',

# Preferences page
'mypreferences'     => 'Haaku a tau manako',
'prefsnologin'      => 'Ai la hu ki loto',
'prefs-rc'          => 'Hikihikiaga mogoia',
'searchresultshead' => 'Kumi',

# Recent changes
'recentchanges' => 'Hikihikiaga mogoia',
'hist'          => 'Liu onoono atu ki tua',

# Recent changes linked
'recentchangeslinked' => 'Falu hikihiki',

# Upload
'upload'            => 'Fakafano e faila',
'uploadbtn'         => 'Fakafano e faila',
'uploadnologin'     => 'Ai la hu ki loto',
'filedesc'          => 'Fakakatoakatoa',
'fileuploadsummary' => 'Fakakatoakatoa:',
'watchthisupload'   => 'Onoono e lau e',

# File description page
'filehist-deleteone' => 'tamate',

# File deletion
'filedelete-submit' => 'Tamate',

# Random page
'randompage' => 'Lau fifili',

'brokenredirects-edit'   => '(fakahakohako)',
'brokenredirects-delete' => '(tamate)',

# Miscellaneous special pages
'newpages-username' => 'Matahigoa he tagata:',
'move'              => 'Une',
'movethispage'      => 'Une e lau e',

# Book sources
'booksources-go' => 'Fano',

# Special:LinkSearch
'linksearch-ok' => 'Kumi',

# Watchlist
'watchlist'     => 'Ko e haaku lau kitekite',
'mywatchlist'   => 'Ko e haaku lau kitekite',
'watchnologin'  => 'Ai la hu ki loto',
'watch'         => 'Kitekite',
'watchthispage' => 'Onoono e lau e',

# Delete
'delete-legend' => 'Tamate',

# Protect
'prot_1movedto2' => '[[$1]] kua une ke he [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Fakahakohako',
'restriction-move' => 'Une',

# Undelete
'undelete-search-submit' => 'Kumi',

# Contributions
'contributions' => 'Tau lagomatai tagata',
'mycontris'     => 'Haaku a tau lagomatai',

'sp-contributions-submit' => 'Kumi',

# What links here
'whatlinkshere' => 'Ko e tau matutakiaga he mena e',

# Block/unblock
'ipbreason'          => 'Kakano:',
'ipblocklist-submit' => 'Kumi',

# Move page
'movenologin' => 'Ai la hu ki loto',
'move-watch'  => 'Onoono e lau e',
'movedto'     => 'kua une ke he',
'1movedto2'   => '[[$1]] kua une ke he [[$2]]',
'movereason'  => 'Kakano:',

# Namespace 8 related
'allmessages' => 'Tau fakailoaga',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Haaku a tau manako',
'tooltip-pt-logout'      => 'Hu mai ki tua',
'tooltip-p-logo'         => 'Matapatu Lau',

# Special:NewFiles
'ilsubmit' => 'Kumi',

# Multipage image navigation
'imgmultigo' => 'Fano!',

# Table pager
'table_pager_limit_submit' => 'Fano',

# Special:Version
'version-specialpages' => 'Tau Lau Mahuiga',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kumi',

# Special:SpecialPages
'specialpages' => 'Tau Lau Mahuiga',

);

==> mediawiki-1.17.4.tar.gz: mediawiki-1.17.4/languages/messages/MessagesNiu.php <==
<?php
/** Niuean (ko e vagahau Niuē)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Rotemliss
 * @author Sioneholof
 */

$messages = array(
# Dates
'sunday'        => 'Aho Tapu',
'monday'        => 'Aho Gofua',
'tuesday'       => 'Aho Ua',
'wednesday'     => 'Aho Lotu',
'thursday'      => 'Aho Tuloto',
'friday'        => 'Aho Falaile',
'saturday'      => 'Aho Faiumu',
'january'       => 'Ianuali',
'february'      => 'Fepuali',
'march'         => 'Masi',
'april'         => 'Apelila',
'may_long'      => 'Me',
'june'          => 'Iuni',
'july'          => 'Iulai',
'august'        => 'Aokuso',
'september'     => 'Sepetema',
'october'       => 'Oketopa',
'november'      => 'Novema',
'december'      => 'Tesemo',
'january-gen'   => 'Ianuali',
'february-gen'  => 'Fepuali',
'march-gen'     => 'Masi',
'april-gen'     => 'Apelila',
'may-gen'       => 'Me',
'june-gen'      => 'Iuni',
'july-gen'      => 'Iulai',
'august-gen'    => 'Aokuso',
'september-gen' => 'Sepetema',
'october-gen'   => 'Oketopa',
'november-gen'  => 'Novema',
'december-gen'  => 'Tesemo',
'may'           => 'Me',

'article'    => 'Tohi Tala',
'cancel'     => 'Tiaki',
'mytalk'     => 'Haaku tutala',
'navigation' => 'Navikati',

# Cologne Blue skin
'qbedit'         => 'Fakahakohako',
'qbspecialpages' => 'Tau Lau Mahuiga',

'help'             => 'Lagomatai',
'search'           => 'Kumi',
'searchbutton'     => 'Kumi',
'go'               => 'Fano',
'searcharticle'    => 'Fano',
'history_short'    => 'Liu onoono atu ki tua',
'printableversion' => 'Mitaki lolomi',
'permalink'        => 'Matutakiaga mautumau',
'edit'             => 'Fakahakohako',
'delete'           => 'Tamate',
'protect'          => 'Puipui',
'talk'             => 'Fakatutala',
'toolbox'          => 'Puha Mena Gahua',
'otherlanguages'   => 'Ke he falu vagahau',
'jumptonavigation' => 'navikati',
'jumptosearch'     => 'kumi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Hagaao ke he {{SITENAME}}',
'currentevents'        => 'Tau Fakaholoaga Mogonei',
'edithelp'             => 'Lagomatai ke he Fakahakohako',
'mainpage'             => 'Matapatu Lau',
'mainpage-description' => 'Matapatu Lau',
'portal'               => 'Maaga ke Matutaki',
'privacy'              => 'Ko e puipuiaga ke he tau talahauaga mo e talahauaga fakatagata',

'youhavenewmessages'      => 'Fai $1 ($2).',
'newmessageslink'         => 'tau tohi foou',
'youhavenewmessagesmulti' => 'Fai tohi foou a koe he $1',
'editsection'             => 'fakahakohako',
'editold'                 => 'fakahakohako',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Lau he tagata',

# General errors
'viewsource' => 'Kitekite ke mouaga',

# Login and logout pages
'welcomecreation'         => '== Fakalofa atu, kua fiafia ke hu mai $1 ==
Kua talaga e haau a poko.
Ua nimo ke hiki e haau tau [[Special:Preferences|manako {{SITENAME}}]].',
'yourname'                => 'Matahigoa he tagata:',
'yourpassword'            => 'Kupu fufu:',
'yourpasswordagain'       => 'Liu lolomi e kupu fufu:',
'remembermypassword'      => 'Manatu e haaku loko ini (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'                   => 'Hu ki loto',
'nav-login-createaccount' => 'Hu ki loto / talaga e poko',
'userlogin'               => 'Hu ki loto / talaga e poko',
'logout'                  => 'Hu mai ki tua',
'userlogout'              => 'Hu mai ki tua',
'notloggedin'             => 'Ai la hu ki loto',
'createaccount'           => 'Talaga e poko',
'gotaccountlink'          => 'Hu ki loto',

# Edit pages
'summary'            => 'Fakakatoakatoa:',
'minoredit'          => 'Ko e fakahakohako fakatote',
'watchthis'          => 'Onoono e lau e',
'savearticle'        => 'Taofi e lau',
'showpreview'        => 'Fakakite e foliga',
'showdiff'           => 'Fakakite e tau hikihiki',
'whitelistedittitle' => 'Kua lata ke loko ini ke fakahakohako',
'loginreqlink'       => 'hu ki loto',

# History pages
'currentrev'          => 'Kitekiteaga mogonei',
'currentrevisionlink' => 'Kitekiteaga mogonei',

# Preferences page
'mypreferences'     => 'Haaku a tau manako',
'prefsnologin'      => 'Ai la hu ki loto',
'prefs-rc'          => 'Hikihikiaga mogoia',
'searchresultshead' => 'Kumi',
'youremail'         => 'Meli hila:',
'username'          => 'Matahigoa he tagata:',
'email'             => 'Meli hila',

# Recent changes
'recentchanges' => 'Hikihikiaga mogoia',
'hist'          => 'Liu onoono atu ki tua',

# Recent changes linked
'recentchangeslinked'         => 'Falu hikihiki',
'recentchangeslinked-feed'    => 'Falu hikihiki',
'recentchangeslinked-toolbox' => 'Falu hikihiki',

# Upload
'upload'            => 'Fakafano e faila',
'uploadbtn'         => 'Fakafano e faila',
'uploadnologin'     => 'Ai la hu ki loto',
'filedesc'          => 'Fakakatoakatoa',
'fileuploadsummary' => 'Fakakatoakatoa:',
'watchthisupload'   => 'Onoono e lau e',

# File description page
'filehist-deleteone' => 'tamate',

# File deletion
'filedelete-submit' => 'Tamate',

# Random page
'randompage' => 'Lau fifili',

'brokenredirects-edit'   => 'fakahakohako',
'brokenredirects-delete' => 'tamate',

# Miscellaneous special pages
'newpages-username' => 'Matahigoa he tagata:',
'move'              => 'Une',
'movethispage'      => 'Une e lau e',

# Book sources
'booksources-go' => 'Fano',

# Special:LinkSearch
'linksearch-ok' => 'Kumi',

# Watchlist
'watchlist'     => 'Ko e haaku lau kitekite',
'mywatchlist'   => 'Ko e haaku lau kitekite',
'watchnologin'  => 'Ai la hu ki loto',
'watch'         => 'Kitekite',
'watchthispage' => 'Onoono e lau e',

# Delete
'delete-legend' => 'Tamate',

# Protect
'prot_1movedto2' => '[[$1]] kua une ke he [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Fakahakohako',
'restriction-move' => 'Une',

# Undelete
'undelete-search-submit' => 'Kumi',

# Contributions
'contributions' => 'Tau lagomatai tagata',
'mycontris'     => 'Haaku a tau lagomatai',

'sp-contributions-submit' => 'Kumi',

# What links here
'whatlinkshere' => 'Ko e tau matutakiaga he mena e',

# Block/unblock
'ipbreason'          => 'Kakano:',
'ipblocklist-submit' => 'Kumi',

# Move page
'movenologin' => 'Ai la hu ki loto',
'move-watch'  => 'Onoono e lau e',
'movedto'     => 'kua une ke he',
'1movedto2'   => '[[$1]] kua une ke he [[$2]]',
'movereason'  => 'Kakano:',

# Namespace 8 related
'allmessages' => 'Tau fakailoaga',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Haaku a tau manako',
'tooltip-pt-logout'      => 'Hu mai ki tua',
'tooltip-p-logo'         => 'Matapatu Lau',

# Special:NewFiles
'ilsubmit' => 'Kumi',

# Multipage image navigation
'imgmultigo' => 'Fano!',

# Table pager
'table_pager_limit_submit' => 'Fano',

# Special:Version
'version-specialpages' => 'Tau Lau Mahuiga',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kumi',

# Special:SpecialPages
'specialpages' => 'Tau Lau Mahuiga',

);
